@@ -26,9 +26,8 @@ class Plugins:
 
     def monitors_inform(self, tlist):
         for p in self._plugin_list:
-            check_plugin_key = "check-ext-" + p.name
             for t in tlist:
-                if check_plugin_key in t.config:
+                if p.name in t.config.get("plugin", []):
                     self._plugs_needed.add(p.name)
 
     def monitors_init(self):
@@ -72,8 +71,7 @@ class Plugins:
         for p in self._plugin_list:
             if p.name not in self._plugs_needed:
                 continue
-            check_plugin_key = "check-ext-" + p.name
-            if check_plugin_key not in test_config:
+            if p.name not in test_config.get("plugin", []):
                 continue
             result = p.test_check(yt)
             if result:
